#
# spec file for package timescaledb
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         pgname  postgresql96
%define         sname   timescaledb
%define         priority    %{pgname}
Version:        1.0.0
Release:        lp152.2.30
Summary:        A time-series database extension for PostgreSQL
License:        Apache-2.0
Group:          Productivity/Databases/Tools
URL:            https://www.timescale.com/
Source:         https://github.com/timescale/%{sname}/releases/download/%{version}/%{sname}-%{version}.tar.gz
BuildRequires:  %{pgname}-devel
BuildRequires:  %{pgname}-server
BuildRequires:  cmake >= 3.4
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  update-alternatives
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
%requires_eq    %{pgname}-server
%if "%{pgname}" == ""
Name:           %{sname}
ExclusiveArch:  do_not_build
%else
Name:           %{pgname}-%{sname}
%endif

%description
TimescaleDB is a database for making SQL more scalable for
time-series data. It is engineered up from PostgreSQL, providing
automatic partitioning across time and space (partitioning key), as
well as full SQL support.

TimescaleDB is packaged as a PostgreSQL extension.

See https://www.timescale.com/

%prep
%setup -q -n %{sname}
# Remove static .so
rm -fv %{sname}.so

%build
export PATH="$PATH:%{_prefix}/lib/%{pgname}/bin"
# No-as-needed is mandatory for Build on Leap42/SLE12
%cmake -DCMAKE_EXE_LINKER_FLAGS="-Wl,--no-as-needed -Wl,--no-undefined -Wl,-z,now" \
       -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--no-as-needed" \
       -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--no-as-needed -Wl,--no-undefined -Wl,-z,now" \
  ..

make USE_PGXS=1 %{?_smp_mflags}

%install
export PATH="$PATH:%{_prefix}/lib/%{pgname}/bin"
%cmake_install USE_PGXS=1 install DESTDIR=%{buildroot}

%fdupes %{buildroot}/%{_datadir}/%{pgname}/extension

#%%check
# Need to be finished when we found pg_regress

%files
%defattr(-,root,root)
%license LICENSE-APACHE NOTICE
%doc README.md CONTRIBUTING.md CHANGELOG.md docs
%{_prefix}/lib/%{pgname}/%{_lib}/%{sname}*.so
%{_datadir}/%{pgname}/extension/%{sname}*

%changelog
* Wed Nov 28 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to final release version 1.0.0 (2018-10-31)
  For complete changelog see
  https://github.com/timescale/timescaledb/releases
  or CHANGELOG file packaged
- LICENSE file was renammed to LICENSE-APACHE
- Packaging renew spec with spec-cleaner -m
* Fri May 18 2018 jengelh@inai.de
- Trim redundancies from the description.
* Sat May  5 2018 bruno@ioda-net.ch
- Update to release 0.9.2 (2018-05-04)
  + High-level changes
    Fixed handling of DISCARD ALL command when parallel workers are
    involved, which sometimes caused the extension to complain it
    was not preloaded
    User permission bug fix where users locating TRIGGER permissions
    in a database could not insert data into a hypertable
  + Fixes for some issues with 32-bit architectures
- Changes for 0.9.1
  + High-level changes
    For this release only, you will need to restart the database
    before running ALTER EXTENSION
    Several edge cases regarding CTEs addressed
    Updated preloader with better error messaging and fixed edge case
    ABI compatibility with latest PostgreSQL to help catch any
    breaking changes
- Changes for 0.9.0
  + When updating your database, you should connect using
    psql with the -X flag to prevent any .psqlrc commands from
    accidentally triggering the load of a previous DB version.
  + High-level changes
    Support for multiple extension versions on different databases
    in the same PostgreSQL instance.
    This allows different databases to be updated independently
    and provides for smoother updates between versions. No
    more spurious errors in the log as the extension is being
    updated, and new versions no longer require a restart of
    the database.
  + Streamlined update process for smaller binary/package sizes
  + Significant refactoring to simplify and improve codebase,
    including improvements to error handling, security/permissions
  + Corrections to edge-case scenarios involving dropping schemas,
    hypertables, dimensions, and more
  + Correctness improvements through propagating reloptions from main
    table to chunk tables and blocking ONLY commands that try to alter
    hypertables (i.e., changes should be applied to chunks as well)
  + Addition of a migrate_data option to create_hypertable to allow
    non-empty tables to be turned into hypertables without separate
    creation & insertion steps. Note, this option may take a while
    if the original table has lots of data
  + Support for ALTER TABLE RENAME CONSTRAINT
  + Support for adjusting the number of partitions for a space dimension
  + Improvements to tablespace handling
* Tue Feb  6 2018 bruno@ioda-net.ch
- Adapt cmake ld flags (no-as-needed) for build on Leap 42x/SLE12
* Sun Feb  4 2018 bruno@ioda-net.ch
- initial package
